#!/usr/bin/python
#
# Copyright 2018-2021 Polyaxon, Inc.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#      http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from polyaxon.polypod.compiler.converters.kubeflow.mpi_job import MPIJobConverter
from polyaxon.polypod.compiler.converters.kubeflow.mx_job import MXJobConverter
from polyaxon.polypod.compiler.converters.kubeflow.pytroch_job import (
    PytorchJobConverter,
)
from polyaxon.polypod.compiler.converters.kubeflow.tf_job import TfJobConverter
from polyaxon.polypod.compiler.converters.kubeflow.xgboost_job import (
    XGBoostJobConverter,
)
